componenttools.copy_components_and_remove_spanners
==================================================

.. autofunction:: abjad.tools.componenttools.copy_components_and_remove_spanners.copy_components_and_remove_spanners
   :noindex:
